Re: [Libreoffice] Segmentation faults in unit tests

2011-02-13 Thread Francois Tigeot
On Sun, Feb 13, 2011 at 11:56:21PM +0100, Francois Tigeot wrote:
> On Sun, Feb 13, 2011 at 09:30:17PM +, Caolán McNamara wrote:
> > 
> > See
> > http://wiki.documentfoundation.org/Development/How_to_debug#Debugging_cppunit_tests

There's a problem with the cppunit debugging implementation.

When I export DEBUGCPPUNIT=true the build is suspended each time there's
an exception:

[...]
/bootstrap/clone/impress/sd/qa/unit/../../unxdflyx3.pro/misc/qa_unit"
:
[1]  + 21339 suspended (tty output)  time gmake

I have to type fg by hand in the shell to let the process continue. Hours of
compilation can be lost if I forget to monitor the build.

-- 
Francois Tigeot
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [Patch] Small bug fixes for SVG import

2011-02-13 Thread KUROSAWA, Takeshi
Hi all,

Here are some tiny patches to fix bugs in SVG import.

0001: Check opacity for == operator
Sometimes, LilbreOffice doesn't handle opacity value.
Example:
http://gnome-colors.googlecode.com/svn/trunk/gnome-colors/gnome-colors-common/scalable/actions/document-properties.svg
The patch fixes this problem.

0002: Fix color serialization
Sometimes, LibreOffice fails to import fill or stroke colors (when
using File -> Open)
Example:
http://gnome-colors.googlecode.com/svn/trunk/gnome-colors/gnome-colors-common/scalable/actions/edit-redo.svg
Treat color value as hex.

0003:Relax paint url parsing (fix fdo#34205)
LibreOffice doesn't allow ' or " between "url(" and "#". As a result,
gradients using url('#foo') syntax aren't imported.
Bug 34205 – SVG import: transparency gradients incorrect
https://bugs.freedesktop.org/show_bug.cgi?id=34205

0004: Ensure writing styles for text
Currently, when a text element doesn't have presentation attributes or
styles, style information is not written (when using File -> Open).
So the text has zero width and is wrapped wrongly.
This patch ensures that filter writes style information if a text has no styles.
See attached text3.svg. Black text ("Hello") will be wrapped wrongly.

All patches are under LGPLv3 / MPL.

cheers,
--
Kurosawa Takeshi 
From 7264908a3058c34b5a72e8ce274c1c8e7ccbad02 Mon Sep 17 00:00:00 2001
From: Takeshi Kurosawa 
Date: Mon, 14 Feb 2011 15:21:41 +0900
Subject: [PATCH 1/4] Check opacity for == operator

Or opacity is ignored.
---
 filter/source/svg/gfxtypes.hxx |2 ++
 1 files changed, 2 insertions(+), 0 deletions(-)

diff --git a/filter/source/svg/gfxtypes.hxx b/filter/source/svg/gfxtypes.hxx
index 60e6a6c..0a07094 100644
--- a/filter/source/svg/gfxtypes.hxx
+++ b/filter/source/svg/gfxtypes.hxx
@@ -275,6 +275,7 @@ inline bool operator==(const State& rLHS, const State& rRHS )
 rLHS.mbVisibility==rRHS.mbVisibility &&
 rLHS.meFillType==rRHS.meFillType &&
 rLHS.mnFillOpacity==rRHS.mnFillOpacity &&
+rLHS.mnOpacity==rRHS.mnOpacity &&
 rLHS.meStrokeType==rRHS.meStrokeType &&
 rLHS.mnStrokeOpacity==rRHS.mnStrokeOpacity &&
 rLHS.meViewportFillType==rRHS.meViewportFillType &&
@@ -319,6 +320,7 @@ struct StateHash
 ^  size_t(rState.mbVisibility)
 ^  size_t(rState.meFillType)
 ^  size_t(rState.mnFillOpacity)
+^  size_t(rState.mnOpacity)
 ^  size_t(rState.meStrokeType)
 ^  size_t(rState.mnStrokeOpacity)
 ^  size_t(rState.meViewportFillType)
-- 
1.7.1

From 38fe5587d887efc468393b4df4caed1f7604f63c Mon Sep 17 00:00:00 2001
From: Takeshi Kurosawa 
Date: Mon, 14 Feb 2011 15:23:20 +0900
Subject: [PATCH 2/4] Fix color serialization

The are hex values.
---
 filter/source/svg/svgreader.cxx |6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/filter/source/svg/svgreader.cxx b/filter/source/svg/svgreader.cxx
index 9ccd3b7..44fa416 100644
--- a/filter/source/svg/svgreader.cxx
+++ b/filter/source/svg/svgreader.cxx
@@ -410,13 +410,13 @@ struct AnnotatingVisitor
 const sal_uInt8 nGreen( toByteColor(rColor.g) );
 const sal_uInt8 nBlue ( toByteColor(rColor.b)  );
 aBuf.append( sal_Unicode('#') );
-if( nRed < 10 )
+if( nRed < 0x10 )
 aBuf.append( sal_Unicode('0') );
 aBuf.append( sal_Int32(nRed), 16 );
-if( nGreen < 10 )
+if( nGreen < 0x10 )
 aBuf.append( sal_Unicode('0') );
 aBuf.append( sal_Int32(nGreen), 16 );
-if( nBlue < 10 )
+if( nBlue < 0x10 )
 aBuf.append( sal_Unicode('0') );
 aBuf.append( sal_Int32(nBlue), 16 );
 
-- 
1.7.1

From cf0c6d64bb3190743ce7237c75197c8f691aafbe Mon Sep 17 00:00:00 2001
From: Takeshi Kurosawa 
Date: Mon, 14 Feb 2011 15:24:11 +0900
Subject: [PATCH 3/4] Relax paint url parsing (fix fdo#34205)

Allow ' and " around parens.
---
 filter/source/svg/parserfragments.cxx |4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/filter/source/svg/parserfragments.cxx b/filter/source/svg/parserfragments.cxx
index c515e85..95811d4 100644
--- a/filter/source/svg/parserfragments.cxx
+++ b/filter/source/svg/parserfragments.cxx
@@ -560,9 +560,9 @@ bool parsePaintUri( std::pair& o_rPaintUri,
 const bool bRes = parse(sPaintUri,
 //  Begin grammar
 (
-str_p("url(#") >>
+str_p("url(") >> !( str_p("'") | str_p("\"") ) >> ("#") >>
 (+alnum_p)[assign_a(o_rPaintUri)] >>
-str_p(")") >>
+!( str_p("'") | str_p("\"") ) >> str_p(")") >>
 *( str_p("none")[assign_a(io_rColor.second,false)] |
str_p("currentColor")[assign_a(io_rColor.second,true)] |
ColorGrammar(io_rColor.first)
-- 
Configure bugmail: https://bugs.freedesktop.org/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are on the CC list for the bug.
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PUSHED] [Patch] Remove bogus comments and dead code from editeng

2011-02-13 Thread Arnaud Versini
Hi,

Next part, no reformating this time.

thanks

2011/2/13 Thomas Arnhold 

> Hi,
>
> nice, thanks for this! I pushed it. As far as I know there is no need to
> reformat the code, because this should be done by a script some time
> later (and we want to be compatible to diffs from OOo).
>
> Thomas
>
> On 02/13/2011 03:29 PM, Arnaud Versini wrote:
> > Hi,
> >
> > Remove some comments from editeng module. Patch under LGPLv3+/MPL.
> >
> > Thanks
> >
> > --
> > Arnaud Versini
> >
> >
> >
> > ___
> > LibreOffice mailing list
> > LibreOffice@lists.freedesktop.org
> > http://lists.freedesktop.org/mailman/listinfo/libreoffice
>
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice
>



-- 
Arnaud Versini
From 1bcc60004abf4e30139e533731fea4a9da8cf821 Mon Sep 17 00:00:00 2001
From: Arnaud Versini 
Date: Sun, 13 Feb 2011 18:43:56 +0100
Subject: [PATCH] Remove bogus comments and dead code from editeng, next part.

---
 editeng/source/items/justifyitem.cxx   |   23 +---
 editeng/source/items/svxfont.cxx   |   42 
 editeng/source/items/writingmodeitem.cxx   |1 -
 editeng/source/items/xmlcnitm.cxx  |1 -
 editeng/source/misc/SvXMLAutoCorrectImport.cxx |2 -
 editeng/source/misc/SvXMLAutoCorrectImport.hxx |1 -
 editeng/source/misc/acorrcfg.cxx   |4 -
 editeng/source/misc/hangulhanja.cxx|   80 
 editeng/source/misc/splwrap.cxx|4 +-
 editeng/source/misc/txtrange.cxx   |   17 -
 editeng/source/misc/unolingu.cxx   |   67 +---
 11 files changed, 5 insertions(+), 237 deletions(-)

diff --git a/editeng/source/items/justifyitem.cxx b/editeng/source/items/justifyitem.cxx
index e6dc9db..5b4cb50 100644
--- a/editeng/source/items/justifyitem.cxx
+++ b/editeng/source/items/justifyitem.cxx
@@ -44,14 +44,12 @@
 #include 
 #include 
 
-// STATIC DATA ---
 
 TYPEINIT1_FACTORY( SvxHorJustifyItem, SfxEnumItem, new SvxHorJustifyItem(SVX_HOR_JUSTIFY_STANDARD, 0) );
 TYPEINIT1_FACTORY( SvxVerJustifyItem, SfxEnumItem, new SvxVerJustifyItem(SVX_VER_JUSTIFY_STANDARD, 0) );
 
 using namespace ::com::sun::star;
 
-// class SvxHorJustifyItem ---
 
 
 SvxHorJustifyItem::SvxHorJustifyItem( const USHORT nId ) :
@@ -65,7 +63,6 @@ SvxHorJustifyItem::SvxHorJustifyItem( const SvxCellHorJustify eJustify,
 {
 }
 
-//
 
 SfxItemPresentation SvxHorJustifyItem::GetPresentation
 (
@@ -88,7 +85,6 @@ SfxItemPresentation SvxHorJustifyItem::GetPresentation
 return SFX_ITEM_PRESENTATION_NONE;
 }
 
-//
 
 bool SvxHorJustifyItem::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
 {
@@ -185,7 +181,6 @@ bool SvxHorJustifyItem::PutValue( const uno::Any& rVal, BYTE nMemberId )
 return true;
 }
 
-//
 
 XubString SvxHorJustifyItem::GetValueText( USHORT nVal ) const
 {
@@ -193,14 +188,12 @@ XubString SvxHorJustifyItem::GetValueText( USHORT nVal ) const
 return EE_RESSTR(RID_SVXITEMS_HORJUST_STANDARD + nVal);
 }
 
-//
 
 SfxPoolItem* SvxHorJustifyItem::Clone( SfxItemPool* ) const
 {
 return new SvxHorJustifyItem( *this );
 }
 
-//
 
 SfxPoolItem* SvxHorJustifyItem::Create( SvStream& rStream, USHORT ) const
 {
@@ -208,14 +201,13 @@ SfxPoolItem* SvxHorJustifyItem::Create( SvStream& rStream, USHORT ) const
 rStream >> nVal;
 return new SvxHorJustifyItem( (SvxCellHorJustify)nVal, Which() );
 }
-//
+
 
 USHORT SvxHorJustifyItem::GetValueCount() const
 {
 return SVX_HOR_JUSTIFY_REPEAT + 1;	// letzter Enum-Wert + 1
 }
 
-// class SvxVerJustifyItem ---
 
 SvxVerJustifyItem::SvxVerJustifyItem( const USHORT nId ) :
 SfxEnumItem( nId, (USHORT)SVX_VER_JUSTIFY_STANDARD )
@@ -228,7 +220,6 @@ SvxVerJustifyItem::SvxVerJustifyItem( const SvxCellVerJustify eJustify,
 {
 }
 
-//
 
 SfxItemPresentation SvxVerJustifyItem::GetPresentation
 (
@@ -252,7 +243,6 @@ SfxItemPresentation SvxVerJustifyItem::GetPresentation
 return SFX_ITEM_PRESENTATION_NONE;
 }
 
-//
 
 bool SvxVerJustifyItem::QueryValue( uno::Any& rVal, BYTE nMemberId ) const
 {
@@ -337,7 +327,6 @@ bool SvxVerJustifyItem::PutValue( const uno::Any& rVal, B

Re: [Libreoffice] HTML formatting in comments?

2011-02-13 Thread Thomas Arnhold
Hi Cedric,

somewhere I read, that IDL files are _mostly_ files with *.idl extension
(I don't remember precisely where I read this). If we are really sure
about these files we could publish this as an Easy Hack.

What do you think about this?

Thomas

On 02/04/2011 08:19 AM, Cedric Bosdonnat wrote:
> Hi Thomas,
> 
> On Thu, 2011-02-03 at 18:07 +0100, Thomas Arnhold wrote:
>> Ok, didn't know, that idl files get handled another way. How do we
>> clearly identify IDL and related files, which shouldn't be handled by
>> doxygen?! Are these only files with the idl extension? And is the
>> doxygen documentation complete without these files?
> 
> IMHO the files that should use that custom markup should only be the
> *.idl files (mostly located in the offapi module).
> 
> I would say that all use of that markup in hxx files should be banned /
> changed. I know that some files are using it to produce the doc linked
> here on OOo website:
> 
> http://api.openoffice.org/docs/cpp/ref/names/index.html
> 
>> As an simple alternative we could define aliases for TRUE/FALSE and so
>> on with doxygen, say it replaces  with TRUE.
> 
> Well, a simple script that spots all the occurences of these tags in C++
> would help as well. It could at least show us the files containing
> comments to switch to Doxygen documentation style. Then sed is your
> friend for this kind of boring job :)
> 

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] Undo Redo Re: [REVIEW] Re: SmNodeToTextVisitor Fixes

2011-02-13 Thread Luke Dixon
Hi Michael, Jonas,

On Fri, 2011-02-11 at 10:15 +, Michael Meeks wrote:
>   Quick question, while I'm here: what are the blockers for enabling this
> by default on master ? was it undo/redo ? or do we have any malingering
> known crashers / mis-features left.

I think Jonas fixed the crash I noticed.
There are 2 more bugs at bugzilla.freedesktop.org, I don't think they
would be too difficult to fix.

It seems that undo/redo is the major one and I just worked out why
undo/redo wasn't working, noticed it while looking at Caolán's unit
tests for starmath. I've attached the patch.

I made it also update the formula when undoing or redoing stuff. I
didn't enable updating only as an experimental feature, as I don't quite
get why it doesn't update already. It looked a little bad when undoing
from the visual formula editor. I hope it will be okay :)

I noticed that when undoing the cursor position goes to the front of the
formula, not sure that is too easy to fix, but I figure having undo is
better than not. Perhaps I could update the Easy Hack to be for this
instead.

It would be great to have Jonas' great work on by default, and with
undo/redo, perhaps it is now possible?

Regards,
Luke
>From 9851ff6a87a3701fa5387aeccc1a7fdd3dd05e07 Mon Sep 17 00:00:00 2001
From: Luke Dixon <6b8b4...@gmail.com>
Date: Sun, 13 Feb 2011 16:28:22 +
Subject: [PATCH] Make Undo & Redo work with the visual formula editor.

---
 starmath/source/cursor.cxx   |2 +-
 starmath/source/document.cxx |1 +
 2 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/starmath/source/cursor.cxx b/starmath/source/cursor.cxx
index 33ae549..4e65f48 100644
--- a/starmath/source/cursor.cxx
+++ b/starmath/source/cursor.cxx
@@ -1461,7 +1461,7 @@ void SmCursor::EndEdit(){
 SmNodeToTextVisitor(pTree, formula);
 //pTree->CreateTextFromNode(formula);
 pDocShell->aText = formula;
-pDocShell->GetEditEngine().SetText(formula);
+pDocShell->GetEditEngine().SetText(0, formula);
 }
 
 void SmCursor::RequestRepaint(){
diff --git a/starmath/source/document.cxx b/starmath/source/document.cxx
index d98c406..eddbe9b 100644
--- a/starmath/source/document.cxx
+++ b/starmath/source/document.cxx
@@ -1174,6 +1174,7 @@ void SmDocShell::Execute(SfxRequest& rReq)
 (pTmpUndoMgr->*fnDo)( 0 );
 }
 Repaint();
+UpdateText();
 SfxViewFrame* pFrm = SfxViewFrame::GetFirst( this );
 while( pFrm )
 {
-- 
1.7.4

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PUSHED] [Patch] Easy hack: idl removed and translated comments

2011-02-13 Thread Thomas Arnhold
Thanks! I pushed it all.

Thomas

On 02/13/2011 01:26 AM, Michael Münch wrote:
> Hi,
> 
> first attempt so I will take any advise (split the patch into smaller files?).
> License is LGPLv3+/MPL.
> 
> I would have edited the wiki that I am working on this directory but the 
> registration is disabled.
> 
> Regards,
> Michael
> 
> 
> 
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PUSHED] [PATCH] Remove bogus comments

2011-02-13 Thread Thomas Arnhold
Looks good. Thanks! I pushed it.

Didn't know that there are bug numbers like this #b449874#.

Thomas

On 02/13/2011 01:57 AM, Antoine Proulx wrote:
> Hi,
> 
> Here's a patch (another one) who removes bogus comments. It's released under 
> the
> LGPLv3+ / MPL.
> 
> Antoine
> 
> 
> 
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PUSHED] [Patch] Remove bogus comments and dead code from editeng

2011-02-13 Thread Thomas Arnhold
Hi,

nice, thanks for this! I pushed it. As far as I know there is no need to
reformat the code, because this should be done by a script some time
later (and we want to be compatible to diffs from OOo).

Thomas

On 02/13/2011 03:29 PM, Arnaud Versini wrote:
> Hi,
> 
> Remove some comments from editeng module. Patch under LGPLv3+/MPL.
> 
> Thanks
> 
> -- 
> Arnaud Versini
> 
> 
> 
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PUSHED] [PATCH] Remove bogus comments in components and impress

2011-02-13 Thread Thomas Arnhold
Thanks for all of them! I pushed them all.

I deleted one additional line in cui/source/tabpages/numfmt.cxx: "//@
aEdFormat.SetText( aLbFormat.GetSelectEntry() );" as this also belong to
a deleted comment.

Thomas

On 02/13/2011 02:08 PM, Guillaume Poussel wrote:
> Second part.
> 
> 
> 
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] ODF 1.2 and extended

2011-02-13 Thread Cesare Leonardi

Hello all.

I'd like to reopen a discussion that some month ago took place here:
http://listarchives.documentfoundation.org/www/discuss/msg02398.html
It was suggested to discuss it with the developers but Google doesn't 
seem to find other discussions on this topic. So here i am.  :-)


LibreOffice 3.3.0 default file format is like OOo3.x: ODF 1.2 extended.
Let's call it ODF1.2+. The last ratified standard is ODF 1.2 and the 
extended one is not yet ratified.


The question is: why using the extended version by default?
What if ODF1.2 extended will never be ratified? There is someone who is 
pushing for it?
Shouldn't the feature that relies upon ODF1.2+ relegated under 
"experimental feature" or something like that?


It's about interoperability.
If others wants to make software that interact with ODF files, which 
version should they choose? The last standard one, or 1.2+ because the 
main ODF implementation is OOo/LibO?
And what does ODF 1.2 extended mean? Is the extended version of OOo3.0.0 
equals to OOo3.3.0? Or, since it is an in-progress standard, they differ 
in some aspect? In other words, can OOo3.0.0 read a document produced by 
OOo3.3.0?
The "extended" terms doesn't guaranteed this. I'm not a developer and i 
have to google around to be sure to have no surprise in mixed environment.


I'd like to listen LibO develelopers point of view on this topic.

Keep up the good work, folks!
Ciao.

Cesare.
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] build error with cppunit - Making install in DllPlugInTester

2011-02-13 Thread Kishan Bhat
Hi Michael,

I could successfully make dev-install on my lubuntu 10.10, yay!!

I'm sorry I could not provide you with results from the command you
suggested - objdump -T /lib/libdl.so.2. I had formatted and re-installed
lubuntu already.

Thanks for all your help on the ML and the IRC.

On Fri, Feb 11, 2011 at 11:10 PM, Kishan Bhat  wrote:

> Hi Michael,


> Ubuntu-natty dev build from Jan 26 2011.


> Now, I switched back to unbunto 10.10. I'l retry git, make and let know.


>
> On Fri, Feb 11, 2011 at 3:08 PM, Michael Meeks 
> wrote:
>
Hi Kishan,
>
>
>> On Fri, 2011-02-11 at 09:15 +0530, Kishan Bhat wrote:
>>
> > I'm trying to build LO.
>>
>
>>On what platform (out of interest ?) is this some self-build linux
>> by
>
> any chance ? did you somehow disable dynamic linking while configuring
>
> it ? ;-)
>
>
>> > and I get this error: http://pastebin.com/KcMu29Ja
>>
>
>> make[2]: Entering directory
>
> `/home/bhat/git/libo/clone/libs-extern/cppunit/
>> unxlngi6.pro/misc/build/cppunit-1.12.1/src/DllPlugInTester'
>
> /bin/bash ../../libtool --tag=CXX   --mode=link g++   -ldl  -o
>
> DllPlugInTester DllPlugInTester.o
>
> CommandLineParser.o ../../src/cppunit/libcppunit.la -lm
>
> g++ -o .libs/DllPlugInTester DllPlugInTester.o CommandLineParser.o
>
>  -ldl ../../src/cppunit/.libs/libcppunit.so -lm  -Wl,--rpath
>
> -Wl,/home/bhat/git/libo/clone/libs-extern/cppunit/
>> unxlngi6.pro/misc/build/cppunit-1.12.1/ooo-install/lib
>
> ./../src/cppunit/.libs/libcppunit.so: undefined reference to `dlsym'
>
> ./../src/cppunit/.libs/libcppunit.so: undefined reference to `dlopen'
>
> ./../src/cppunit/.libs/libcppunit.so: undefined reference to `dlclose'
>
>
>>Looks like your libdl is causing grief - it would be interesting to
>
> know what:
>
>
>>objdump -T /lib/libdl.so.2
>
>
>>says - surely it must define 'dlsym' ? :-) how could it not ? and
>> your
>
> link line contains that.
>
>
>>ATB,
>
>
>>Michael.
>
>
>> --
>
>  michael.me...@novell.com  <><, Pseudo Engineer, itinerant idiot
>
>
>>
>>
>
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] Calc, Drawing borders with Frame drop down in Format menu - bug in EDITING

2011-02-13 Thread Dietmar
Hi,

I just filed another bug on the borderline topic in calc:
https://bugs.freedesktop.org//show_bug.cgi?id=34226 

There is a bug when using the Frame (de: "Umrandung") drop down menu
from the "Format" menu in calc.

Select a group of cells (e.g. 3x5).
Select e.g. the left side border in the "Umrandung" menu.
Nothing is drawn.

It works only if you draw an entire square around the cells.

Dietmar

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] FOSDEM feedback, re: Improved bug filing form / flow

2011-02-13 Thread Dirk Haun
I attended the "Easy hacks to get involved with"[1] session at FOSDEM.
The item "Improved bug filing form / flow"[2] from the wiki page that
Michael mentioned reminded me of similar issues that the Mozilla guys
apparently had, as mentioned in their presentation[3] on Saturday.

Effectively, "SUMO" as they call it, is a support platform that
provides a customized workflow guiding users who are looking for a
solution to a problem. It will lead them to knowledge base articles or
lets them post a question (in the process bringing up similar
questions that have been asked before) or takes them to a live chat.
Filing a bug would be the last resort.

This is what's running on http://support.mozilla.com/ and lets them
handle (IIRC) 11 million support issues per month.

The good: It's all open source[4]. The bad: It's not "productized"
yet, i.e. it's currently tailor-made for Mozilla's use case. But they
plan to roll it out as a separate product for others to use. "Wait a
few months" was the answer we got.

So, I guess what I'm suggesting is that instead of reinventing the
wheel, someone who's interested in picking up that task may want to
look into this existing system. Check what it does, collect the
requirements that LibreOffice has and possibly cooperate with the
Mozilla folks.

bye, Dirk

[1] http://fosdem.org/2011/schedule/event/easyhacks
[2] 
http://wiki.documentfoundation.org/Development/Easy_Hacks#Improved_bug_filing_form_.2F_flow
[3] http://fosdem.org/2011/schedule/event/mozilla_sumo
[4] https://github.com/mozilla/kitsune
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] compilation and bundled extensions

2011-02-13 Thread Jean-Baptiste Faure
Hi,

I compiled LibO (branch master) on my notebook under Ubuntu 10.04 (x86_64).
All worked fine. It took ~ 4 hours with 2 CPUs underclocked to 63% to
prevent overheating.

I did "make dev-install" to try the result. No problem although I wonder
why this command did not install the bundled extensions.
Is there some option to add to do a complete installation ?

Best regards
JBF

-- 
Seuls des formats ouverts peuvent assurer la pérennité de vos documents.

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [PATCH] Remove bogus comments in components and impress

2011-02-13 Thread Guillaume Poussel
Hi,

Find attached new patches that remove bogus comments (still under
LGPLv3+/MPL) in components and impress.

Comments with kind of 'revision control' (with dates) remain in writer
and binfilter. I will work on writer and write it on the wiki.


Regards,
Guillaume Poussel


0001-Remove-bogus-and-dates-comments-components.patch
Description: Binary data


0001-Remove-bogus-and-dates-comments-impress.patch
Description: Binary data
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] duplicate code (binfilter)

2011-02-13 Thread Tor Lillqvist
Well, all of binfilter *is* more or less duplicate code, isn't that the very 
point of it? (Duplicate of code as it existed at some point back in history.) 
Please, we should stop paying too close attention to binfilter. It is not worth 
it to spend too much time on making it "cleaner" as binfilter is going to be 
removed at some point in the not too distant future anyway. And this I say just 
as my personal opinion, of course.

--tml


___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] Easy Hack

2011-02-13 Thread Bálint Dózsa
Hy Miklos,

Thank you for the help.
Here is the correction patch

Regards,
Balint Dozsa

2011/2/13 Miklos Vajna 

> On Sat, Feb 12, 2011 at 11:34:52AM +0100, Bálint Dózsa <
> dozsabal...@gmail.com> wrote:
> >  void DomainMapperTableHandler::startTable(unsigned int nRows,
> > -  unsigned int /*nDepth*/,
> > +  unsigned int,
>
> The nDepth is a useful info here, so we know the second parameter is a
> depth of something. Please do not remove. (This problem is there in your
> patch at multiple places.)
>
> Thanks.
>
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice
>
>
From 3918138dfc5ea094e603dc46c4421c82ce66f935 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?B=C3=A1lint=20D=C3=B3zsa?= 
Date: Sun, 13 Feb 2011 09:05:06 +0100
Subject: [PATCH] Remove dead code

---
 writerfilter/source/dmapper/DomainMapper.cxx   |5 -
 .../source/dmapper/DomainMapperTableHandler.cxx|3 -
 .../source/dmapper/DomainMapperTableManager.cxx|2 -
 writerfilter/source/dmapper/DomainMapper_Impl.hxx  |5 -
 writerfilter/source/dmapper/FontTable.hxx  |4 -
 writerfilter/source/dmapper/GraphicImport.cxx  |   91 
 writerfilter/source/dmapper/NumberingManager.cxx   |1 -
 writerfilter/source/dmapper/PropertyIds.cxx|   15 ---
 writerfilter/source/dmapper/PropertyMap.cxx|   14 ---
 writerfilter/source/dmapper/PropertyMap.hxx|   10 --
 writerfilter/source/dmapper/SettingsTable.cxx  |7 +-
 writerfilter/source/dmapper/StyleSheetTable.cxx|6 +-
 writerfilter/source/dmapper/ThemeTable.cxx |6 +-
 13 files changed, 4 insertions(+), 165 deletions(-)

diff --git a/writerfilter/source/dmapper/DomainMapper.cxx b/writerfilter/source/dmapper/DomainMapper.cxx
index 8584268..3d61400 100644
--- a/writerfilter/source/dmapper/DomainMapper.cxx
+++ b/writerfilter/source/dmapper/DomainMapper.cxx
@@ -2146,8 +2146,6 @@ void DomainMapper::sprm( Sprm& rSprm, PropertyMapPtr rContext, SprmType eSprmTyp
 }
 const FontEntry::Pointer_t pFontEntry(pFontTable->getFontEntry(sal_uInt32(nIntValue)));
 rContext->Insert(eFontName, true, uno::makeAny( pFontEntry->sFontName  ));
-//rContext->Insert(eFontStyle, uno::makeAny( pFontEntry->  ));
-//rContext->Insert(eFontFamily, uno::makeAny( pFontEntry->  ));
 rContext->Insert(eFontCharSet, true, uno::makeAny( (sal_Int16)pFontEntry->nTextEncoding  ));
 rContext->Insert(eFontPitch, true, uno::makeAny( pFontEntry->nPitchRequest  ));
 }
@@ -3088,7 +3086,6 @@ void DomainMapper::sprm( Sprm& rSprm, PropertyMapPtr rContext, SprmType eSprmTyp
 }
 }
 break;
-//break;
 case NS_ooxml::LN_EG_HdrFtrReferences_headerReference: // header reference - not needed
 case NS_ooxml::LN_EG_HdrFtrReferences_footerReference: // footer reference - not needed
 break;
@@ -3448,8 +3445,6 @@ void DomainMapper::table(Id name, writerfilter::Reference::Pointer_t ref)
 dmapper_logger->startElement("table");
 dmapper_logger->attribute("id", (*QNameToString::Instance())(name));
 #endif
-
-// printf ( "DomainMapper::table(0x%.4x)\n", (unsigned int)name);
 m_pImpl->SetAnyTableImport(true);
 switch(name)
 {
diff --git a/writerfilter/source/dmapper/DomainMapperTableHandler.cxx b/writerfilter/source/dmapper/DomainMapperTableHandler.cxx
index dedcd36..0f9a870 100644
--- a/writerfilter/source/dmapper/DomainMapperTableHandler.cxx
+++ b/writerfilter/source/dmapper/DomainMapperTableHandler.cxx
@@ -801,9 +801,6 @@ void DomainMapperTableHandler::startCell(const Handle_t & start,
 #endif
 
 //add a new 'row' of properties
-//if( m_pCellProperties.size() <= sal::static_int_cast< sal_uInt32, sal_Int32>(m_nRowIndex) )
-//m_pCellProperties.push_back( RowProperties_t() );
-//m_pCellProperties[m_nRowIndex].push_back( pProps );
 m_pCellSeq = CellSequencePointer_t(new CellSequence_t(2));
 if (!start.get()) 
 return;
diff --git a/writerfilter/source/dmapper/DomainMapperTableManager.cxx b/writerfilter/source/dmapper/DomainMapperTableManager.cxx
index b5509e8..1ed6ba6 100644
--- a/writerfilter/source/dmapper/DomainMapperTableManager.cxx
+++ b/writerfilter/source/dmapper/DomainMapperTableManager.cxx
@@ -256,7 +256,6 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
 {
 TablePropertyMapPtr pPropMap( new TablePropertyMap );
 const sal_Int16 HORI_LEFT_TOP = 0;
-/*const sal_Int16 HORI_RIGHT_TOP = 1;*/ // currently not used below
 const sal_Int16 VERT_TOP_RIGHT = 2;
 bool bInsertCellProps = true;
 switch ( nIntValue )
@@ -403,7 +402,6 @@ void D
-- 
1.7.1

<>From b6fdd34b092bae64afc52f519ffa120f2e99ea2b Mon Sep 17 00:00:00 2001
From: Takeshi Kurosawa 
Date: Mon, 14 Feb 2011 15:26:21 +0900
Subject: [PATCH 4/4] Ensur

Re: [Libreoffice] Undo Redo Re: [REVIEW] Re: SmNodeToTextVisitor Fixes

2011-02-13 Thread Luke Dixon
Hi Jonas,

On Sun, 2011-02-13 at 21:44 +0100, Jonas Finnemann Jensen wrote:

> It would be major step to get that issue fixed... And you're going the
> right way, but your patch doesn't work if the formula is written in
> multiple lines...
> try, writing the formula 3+3+3 \n \n \n \n +4+4 (replace \n by line
> break not NEWLINE but whitespace linebreak).
> Then in visual editor delete +3, go into the command editor again and
> back into the visual editor and notice that it now says 3+3+4+4+4+4.
> The command editor will say  { 3 + 3 + 4 + 4 }  \n \n \n \n +4+4,
> because the SetText(0, formula) only replaced the first paragraph...
> 

Ah, I guess I got a bit too excited too quickly. I should have known
better than to think it was that easy. :)

> 
> What I understand from editeng_8.cxx line 1621 (see [1]) is that the
> number you pass in setText(0, formula), is the paragraph to be
> replaced by the text...
> The method signature is EditEngine::SetText( sal_uInt16 nPara, const
> XubString& rTxt ), and it calls SelectParagraph(nPara)
> At least that's what I can decrypt from the sources... (I think I've
> seen ROT13 variants that was easier to read).
> 

Yeah, I saw nPara, and thought about it for a couple of seconds, figured
that since SmNodeToTextVisitor puts it all on one line it would be okay.
I thought that through badly :(

> 
> I have no idea how to solve this... Maybe we can
> call EditEngine::UndoActionStart(USHORT nId) (see [2])
> and EditEngine::UndoActionEnd(USHORT nId), before and after the called
> to EditEngine::SetText(formula)...
> But in that case I don't know if we can pass any value as nId, the
> existing ones are defined in [3] (line 64).
> The only place I can see EDITUNDO_INSERT used is to call
> UndoActionStart/End and in one switch case where labels are
> generated...
> 

I had a very bad solution that seemed to work but made the unit tests
not work.
I replaced SetText with:
SmGetActiveView()->GetEditWindow()->SelectAll();
SmGetActiveView()->GetEditWindow()->InsertText(formula);

but it would really need to be done properly.

> 
> We can probably enable the visual editor as an non-default editing
> mode (i.e. activated from toolbar) once the formatting issue is
> addressed... Then when we've integrated it properly, so that users of
> the command editor doesn't feel any uncomfort, we can make it
> default...
> But as long as it discards formatting information (font, bold, color,
> alignment, etc) we probably shouldn't enable it by default... Users
> hate regressions, especially if it eats all their formatting
> information without asking nicely first :)
> 

Oh yeah, forgot about the formatting. Yes, I agree. I guess I just got a
little excited.

I'm very sorry for bothering you with solutions that don't work.
Thanks for putting up with me. :)

Regards,
Luke


___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [PATCH] DECLARE_LIST(TOXControlList, Control*) to std::vector in sw.

2011-02-13 Thread Rafael Dominguez
Well the patch is related to sw, tab entries in Insert->Indexes and Tables
-> Indexes and Tables.


0001-.git-COMMIT_EDITMSG.save.patch
Description: Binary data
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] Segmentation faults in unit tests

2011-02-13 Thread Francois Tigeot
On Sun, Feb 13, 2011 at 09:30:17PM +, Caolán McNamara wrote:
> On Sat, 2011-02-12 at 20:34 +0100, Francois Tigeot wrote:
> > LibreOffice builds now run for almost 3 hours before failing on DragonFly.
> > The errors are always of the same sort: some kind of segmentation fault
> > with an unit test :
> 
> See
> http://wiki.documentfoundation.org/Development/How_to_debug#Debugging_cppunit_tests
> hopefully that'll work for you too to find where the offending throw is
> coming from.

Thanks, Caolán. I was getting by by deactivating tests.

-- 
Francois Tigeot
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] modules to remove? javainstaller2, crashrep

2011-02-13 Thread Christian Lohmaier
Hi *,

On Sun, Feb 13, 2011 at 9:00 PM, Andras Timar  wrote:
>
> components/javainstaller2 and components/crashrep are not built for
> LibreOffice.
>
> AFAIK javainstaller2 is used only by the commercial product
> (StarOffice/OOO).

No, also for OOo, but it is useless to have it, since all that that
installer does is to install the rpms (and a java runtime!) - it has
the option to perform a user-installation IIRC, but that's the only
"advanced" feature it has.
So get rid of it.

> If you do not plan to use and to implement the server
> side of crashrep, it can be removed, too. A few strings less for
> localizers...

Well, as those strings don't change, I don't see a benefit here for localizers.

But no real opinion on this one.

ciao
Christian
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PUSHED] [PATCH] Easy hack: remove obsolete gjc aot compilation

2011-02-13 Thread Thomas Arnhold
I pushed it now. Wanted that someone had a look at it ;)

On 02/13/2011 10:38 PM, Caolán McNamara wrote:
> On Sat, 2011-02-12 at 17:02 +0100, Thomas Arnhold wrote:
>> And I removed configure.cmd as it's a personal file (local paths and so on).
> 
> Yeah, remove that, and the aot removal looks good too. I added that in
> as a desperate measure to shrink the helpcontent2 build time from 28
> hours to 8 or so back in the day when it was build with some java
> tooling and the only free java we had was gcj. Rewrote in c++ ages ago
> so the aot support doesn't do anything useful anymore really. You
> haven't pushed these yet though I think ? Should be ok to do so.
> 
> Of course java returned with the lucene stuff in there, but at least
> openjdk is available. Still would be great to see if clucene would work
> in there instead of lucene.
> 
> C.
> 
> 

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PATCH] Easy hack: remove obsolete gjc aot compilation

2011-02-13 Thread Caolán McNamara
On Sat, 2011-02-12 at 17:02 +0100, Thomas Arnhold wrote:
> And I removed configure.cmd as it's a personal file (local paths and so on).

Yeah, remove that, and the aot removal looks good too. I added that in
as a desperate measure to shrink the helpcontent2 build time from 28
hours to 8 or so back in the day when it was build with some java
tooling and the only free java we had was gcj. Rewrote in c++ ages ago
so the aot support doesn't do anything useful anymore really. You
haven't pushed these yet though I think ? Should be ok to do so.

Of course java returned with the lucene stuff in there, but at least
openjdk is available. Still would be great to see if clucene would work
in there instead of lucene.

C.

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PATCH] Remove Xine

2011-02-13 Thread Julien Nabet

Le 13/02/2011 22:19, Caolán McNamara a écrit :

On Sat, 2011-02-12 at 18:07 +0100, Julien Nabet wrote:
   

Hello,

Here is a patch to remove xine.
 

I think that was an Easy Hack, can you remove it from that list and move
it to the "completed" one, stick you name on it there then.

C.
   
Yes, it was an easy hack and someone already did it for me (I don't have 
a wiki account for the moment)


Julien.
__
Do You Yahoo!?
En finir avec le spam? Yahoo! Mail vous offre la meilleure protection possible contre les messages non sollicités 
http://mail.yahoo.fr Yahoo! Mail 
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] Segmentation faults in unit tests

2011-02-13 Thread Caolán McNamara
On Sat, 2011-02-12 at 20:34 +0100, Francois Tigeot wrote:
> LibreOffice builds now run for almost 3 hours before failing on DragonFly.
> The errors are always of the same sort: some kind of segmentation fault
> with an unit test :

See
http://wiki.documentfoundation.org/Development/How_to_debug#Debugging_cppunit_tests
hopefully that'll work for you too to find where the offending throw is
coming from.

C.

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] compilation and bundled extensions

2011-02-13 Thread Caolán McNamara
On Sun, 2011-02-13 at 11:22 +0100, Jean-Baptiste Faure wrote:
> I did "make dev-install" to try the result. No problem although I wonder
> why this command did not install the bundled extensions.
> Is there some option to add to do a complete installation ?

I wondered this too earlier today, try 

./autogen.sh --with-extension-integration

caolanm->dtardon: Which reminds me, when i did this I didn't seem to get
the python, beanshell, rhino scripting extensions (not that I really
want the beanshell, rhino ones, but I did want the python one)

C.

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PATCH] Remove Xine

2011-02-13 Thread Thomas Arnhold
I did this already, as the registration for the wiki doesn't work at the
moment.

Thomas

On 02/13/2011 10:19 PM, Caolán McNamara wrote:
> On Sat, 2011-02-12 at 18:07 +0100, Julien Nabet wrote:
>> Hello,
>>
>> Here is a patch to remove xine.
> 
> I think that was an Easy Hack, can you remove it from that list and move
> it to the "completed" one, stick you name on it there then.
> 
> C.
> 
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice
> 

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PATCH] Remove Xine

2011-02-13 Thread Caolán McNamara
On Sat, 2011-02-12 at 18:07 +0100, Julien Nabet wrote:
> Hello,
> 
> Here is a patch to remove xine.

I think that was an Easy Hack, can you remove it from that list and move
it to the "completed" one, stick you name on it there then.

C.

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] Easy Hacks: Migrate module descriptions to our wiki

2011-02-13 Thread Christoph Herzog
I'm busy with this easy hack, i.e. filling 
http://wiki.documentfoundation.org/Development/Code_Overview.


It is proposed to copy and paste text from

http://wiki.services.openoffice.org/w/index.php?title=Source_code_directories&oldid=6821

But http://wiki.services.openoffice.org/wiki/Source_code_directories is 
a similar list, yet more complete. Why use the former? License reasons?


And in this context: Can some text from other parts of the OOo Wiki be 
copied and pasted?



___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] Undo Redo Re: [REVIEW] Re: SmNodeToTextVisitor Fixes

2011-02-13 Thread Jonas Finnemann Jensen
Hi Luke,

It seems that undo/redo is the major one and I just worked out why
> undo/redo wasn't working, noticed it while looking at Caolán's unit
> tests for starmath. I've attached the patch.

It would be major step to get that issue fixed... And you're going the right
way, but your patch doesn't work if the formula is written in multiple
lines...
try, writing the formula 3+3+3 \n \n \n \n +4+4 (replace \n by line break
not NEWLINE but whitespace linebreak).
Then in visual editor delete +3, go into the command editor again and back
into the visual editor and notice that it now says 3+3+4+4+4+4.
The command editor will say  { 3 + 3 + 4 + 4 }  \n \n \n \n +4+4, because
the SetText(0, formula) only replaced the first paragraph...

What I understand from editeng_8.cxx line 1621 (see [1]) is that the number
you pass in setText(0, formula), is the paragraph to be replaced by the
text...
The method signature is EditEngine::SetText( sal_uInt16 nPara, const
XubString& rTxt ), and it calls SelectParagraph(nPara)
At least that's what I can decrypt from the sources... (I think I've seen
ROT13 variants that was easier to read).

I have no idea how to solve this... Maybe we can
call EditEngine::UndoActionStart(USHORT nId) (see [2])
and EditEngine::UndoActionEnd(USHORT nId), before and after the called to
EditEngine::SetText(formula)...
But in that case I don't know if we can pass any value as nId, the existing
ones are defined in [3] (line 64).
The only place I can see EDITUNDO_INSERT used is to call UndoActionStart/End
and in one switch case where labels are generated...

But again, there's no documentation, what so ever! So unless we can find the
guy who wrote it, maybe we should just try something and hope it doesn't
introduce a bug somewhere we don't notice...

[1] http://docs.libreoffice.org/editeng/html/editeng_8cxx-source.html#l01621
[2]
http://docs.libreoffice.org/editeng/html/classEditEngine.html#c7a0ff1067cb9e6054be7cfaaa91872c
[3]
http://docs.libreoffice.org/editeng/html/editdata_8hxx-source.html#l00064

It would be great to have Jonas' great work on by default, and with
> undo/redo, perhaps it is now possible?

Undo/redo would be a great step in the right direction, if we don't have it
users will probably consider it a regression...
I recently pushed line deletion using backspace... Now I just need to
implement it using delete...
But apart from that the visual editor does still discards bold, font, color
and alignment information, it wouldn't be hard to retain it... But it would
be hard to edit it intuitively using visual editor, which is why it just
discards this now...
But I would imagine that some people would get rather mad, if we enable a
feature that removes formatting from their formulas...

We can probably enable the visual editor as an non-default editing mode
(i.e. activated from toolbar) once the formatting issue is addressed... Then
when we've integrated it properly, so that users of the command editor
doesn't feel any uncomfort, we can make it default...
But as long as it discards formatting information (font, bold, color,
alignment, etc) we probably shouldn't enable it by default... Users hate
regressions, especially if it eats all their formatting information without
asking nicely first :)

--
Regards Jonas Finnemann Jensen.


On Sun, Feb 13, 2011 at 18:12, Luke Dixon <6b8b4...@gmail.com> wrote:

> Hi Michael, Jonas,
>
> On Fri, 2011-02-11 at 10:15 +, Michael Meeks wrote:
> >   Quick question, while I'm here: what are the blockers for enabling
> this
> > by default on master ? was it undo/redo ? or do we have any malingering
> > known crashers / mis-features left.
>
> I think Jonas fixed the crash I noticed.
> There are 2 more bugs at bugzilla.freedesktop.org, I don't think they
> would be too difficult to fix.
>
> It seems that undo/redo is the major one and I just worked out why
> undo/redo wasn't working, noticed it while looking at Caolán's unit
> tests for starmath. I've attached the patch.
>
> I made it also update the formula when undoing or redoing stuff. I
> didn't enable updating only as an experimental feature, as I don't quite
> get why it doesn't update already. It looked a little bad when undoing
> from the visual formula editor. I hope it will be okay :)
>
> I noticed that when undoing the cursor position goes to the front of the
> formula, not sure that is too easy to fix, but I figure having undo is
> better than not. Perhaps I could update the Easy Hack to be for this
> instead.
>
> It would be great to have Jonas' great work on by default, and with
> undo/redo, perhaps it is now possible?
>
> Regards,
> Luke
>
> ___
> LibreOffice mailing list
> LibreOffice@lists.freedesktop.org
> http://lists.freedesktop.org/mailman/listinfo/libreoffice
>
>
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [Bug 32894] [Task] LibreOffice 3.3.1 release blockers / stoppers

2011-02-13 Thread bugzilla-daemon
https://bugs.freedesktop.org/show_bug.cgi?id=32894

--- Comment #22 from vitriol  2011-02-13 12:12:09 
PST ---
Added bug 34226

-- 
Configure bugmail: https://bugs.freedesktop.org/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are on the CC list for the bug.
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [Bug 32894] [Task] LibreOffice 3.3.1 release blockers / stoppers

2011-02-13 Thread bugzilla-daemon
https://bugs.freedesktop.org/show_bug.cgi?id=32894

vitriol  changed:

   What|Removed |Added

 Depends on||34226

-- 
Configure bugmail: https://bugs.freedesktop.org/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are on the CC list for the bug.
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [Bug 32894] [Task] LibreOffice 3.3.1 release blockers / stoppers

2011-02-13 Thread bugzilla-daemon
https://bugs.freedesktop.org/show_bug.cgi?id=32894

--- Comment #21 from tester8  2011-02-13 12:08:29 PST ---
to vitriol
You need not only wrote that you nominate some bug but also add it to the
"Depends on".

-- 
Configure bugmail: https://bugs.freedesktop.org/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are on the CC list for the bug.
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] modules to remove? javainstaller2, crashrep

2011-02-13 Thread Andras Timar
Hi,

components/javainstaller2 and components/crashrep are not built for
LibreOffice.

AFAIK javainstaller2 is used only by the commercial product
(StarOffice/OOO). If you do not plan to use and to implement the server
side of crashrep, it can be removed, too. A few strings less for
localizers...

Best regards,
Andras
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [PATCH] fixed spelling menues -> menus

2011-02-13 Thread Christina Roßmanith

Hi,

I've removed some 'e's from menues and ouer. It builds successfully.

It's LGPLv3+/MPL.

Christina Rossmanith

>From 96718e8fd485eab2bf261bccf7a34421b297b29a Mon Sep 17 00:00:00 2001
From: Christina Rossmanith 
Date: Sat, 12 Feb 2011 21:19:41 +0100
Subject: [PATCH] fixed spelling menues -> menus

---
 svtools/source/config/menuoptions.cxx |   46 
 1 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/svtools/source/config/menuoptions.cxx b/svtools/source/config/menuoptions.cxx
index a12f1e0..4e814a7 100644
--- a/svtools/source/config/menuoptions.cxx
+++ b/svtools/source/config/menuoptions.cxx
@@ -62,13 +62,13 @@ using namespace ::com::sun::star::uno	;
 
 #define	PROPERTYNAME_DONTHIDEDISABLEDENTRIES	OUString(RTL_CONSTASCII_USTRINGPARAM("DontHideDisabledEntry"	))
 #define	PROPERTYNAME_FOLLOWMOUSEOUString(RTL_CONSTASCII_USTRINGPARAM("FollowMouse"))
-#define PROPERTYNAME_SHOWICONSINMENUES  OUString(RTL_CONSTASCII_USTRINGPARAM("ShowIconsInMenues"))
-#define PROPERTYNAME_SYSTEMICONSINMENUESOUString(RTL_CONSTASCII_USTRINGPARAM("IsSystemIconsInMenus" ))
+#define PROPERTYNAME_SHOWICONSINMENUS   OUString(RTL_CONSTASCII_USTRINGPARAM("ShowIconsInMenus" ))
+#define PROPERTYNAME_SYSTEMICONSINMENUS OUString(RTL_CONSTASCII_USTRINGPARAM("IsSystemIconsInMenus" ))
 
 #define	PROPERTYHANDLE_DONTHIDEDISABLEDENTRIES	0
 #define	PROPERTYHANDLE_FOLLOWMOUSE1
-#define PROPERTYHANDLE_SHOWICONSINMENUES2
-#define PROPERTYHANDLE_SYSTEMICONSINMENUES  3
+#define PROPERTYHANDLE_SHOWICONSINMENUS 2
+#define PROPERTYHANDLE_SYSTEMICONSINMENUS   3
 
 #define PROPERTYCOUNT   4
 
@@ -147,8 +147,8 @@ class SvtMenuOptions_Impl : public ConfigItem
 
 /*-//**
 @short		access method to get internal values
-@descr		These method give us a chance to regulate acces to ouer internal values.
-It's not used in the moment - but it's possible for the feature!
+@descr		These methods give us a chance to regulate access to our internal values.
+It's not used in the moment - but it's possible for the feature (future?)!
 
 @seealso	-
 
@@ -201,7 +201,7 @@ class SvtMenuOptions_Impl : public ConfigItem
 private:
 
 /*-//**
-@short		return list of fix key names of ouer configuration management which represent oue module tree
+@short		return list of fix key names of our configuration management which represent our module tree
 @descr		These methods return a static const list of key names. We need it to get needed values from our
 configuration management.
 
@@ -250,7 +250,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
 bMenuIcons = m_nMenuIcons ? sal_True : sal_False;
 }
 
 // Copy values from list in right order to ouer internal member.
 sal_Int32 nPropertyCount	=	seqValues.getLength()	;
 sal_Int32 nProperty			=	0		;
 for( nProperty=0; nProperty>= m_bFollowMouse;
 }
 break;
-case PROPERTYHANDLE_SHOWICONSINMENUES   :   {
-DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenues\"?" );
+case PROPERTYHANDLE_SHOWICONSINMENUS:   {
+DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenus\"?" );
 seqValues[nProperty] >>= bMenuIcons;
 }
 break;
-case PROPERTYHANDLE_SYSTEMICONSINMENUES		:   {
+case PROPERTYHANDLE_SYSTEMICONSINMENUS	 	:   {
 DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\IsSystemIconsInMenus\"?" );
 seqValues[nProperty] >>= bSystemMenuIcons;
 }
@@ 

[Libreoffice] l10n of patches

2011-02-13 Thread Andras Timar
Hi,

There are still a few patches in build/patches/dev300 which contain
localizable text. When we move to new l10n framework on master this will
become a problem, because we would like to get rid of lo-build.sdf/po
hack. Please decide if these patches should be integrated or deleted.
Otherwise it will be hard to localize the strings in them.

document-password-change-sfx2.diff kohei
helpcontent-scalc-01.diff kohei
impressmedia-features.diff thorsten
min-password-length-helpcontent2.diff kohei, timar
novell-subscription.diff jholesov
ok-cancel-btn-add-accel.diff kohei
optional-outplace-ole.diff thorsten
sfx2-template-category-labels.diff pmladek
writer-doc-comparison-help.diff (commented out) tzvetelina

Many thanks,
Andras
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] Tools - Media Player

2011-02-13 Thread Thomas Arnhold
Christoph thanks for the discussion link and the specs!

On 02/12/2011 10:01 PM, Michael Meeks wrote:
> On Fri, 2011-02-11 at 23:08 +0100, Christoph Noack wrote:
>>> what the heck do we do with "Tools - Media Player"? Do we need this
>>> within an office suite? Is anyone using this?!
> 
>   :-) My suspicion is that ~no-one is using it.

I think the same. If I add an video to a presentation I know what file I
want to add. And if I want a preview of a specific file this should be
done by the filepicker.

>> Without adding too many thoughts, here is the corresponding thread with
>> some answers and the original specification (linked). Maybe this helps
> 
>   The link to the spec. is:
> 
>   http://specs.openoffice.org/appwide/media_player/MediaPlayer.sxw
> 
>   Which (on reading) suggests to me that the only useful uses of this
> beastie is two fold:
> 
>   a) to allow playback controls to appear / be used when playing
>   + presuambly we can / should do this for embedded media
> anyway in some suitably tasteful way.
> 
>   b) to allow video files to be previewed from the gallery
>   + cf. the difficulty of building galleries, and the
> fact that I've never seen any video in one
>   + cf. the fact that I just failed to add an mgp
> or ogg to a gallery, via the properties dialog.
> 
>   So - I think b) is fairly bogus (or the gallery addition code needs
> some real work), a) is a real use-case; it seems we throw up the media
> player for preview sounds in the shipped gallery.

Ah, I didn't see that sound files in the gallery use this player. I my
opinion we could remove "Tools -> Media Player" from the menu and let it
act in the background for the gallery and embed media in documents.

I tested to create a new gallery. There is some kind of lack of user
experience: Open the gallery, then "New theme", tab "Files" and then you
have to click "Find files" at first to scan a directory for media
contents. When this is done all media files get added to the list below
and you could click "Add" or "Add all" to add these files to the
gallery. Paradoxically, if you forget to click "Find files" and directly
go to "Add" this is also possible, but with a very limited list of
supported file formats (only images). That's some kind of strange.

I've added ogg and mpg files and some more formats into the gallery.
Works fine. Only lack is the list of supported formats. I manually added
a flv-file with "Insert -> Movie and Sound" (thats the player). But you
have to choose "All files". Within the gallery there is no such option.
With the consequence that I can't add flv files to it, despite the fact
that the player plays it ;)


With "Insert" you have two possible options to add media content to the
document: "Insert -> Movie and Sound" or "Insert -> Object ->
Video/Sound". I think the second is deprecated as it doesn't really
work. The gallery does add sounds and videos like "Movie and Sound".

>   So - IMHO the player-let is useful, but I'd be amazed if people really
> used it in anger; it is rather lame. Removing it from the menus in
> everything but impress might make some sense (?)

Yeah for impress it is very useful. But why remove the possibility to
add videos and other media to the files. I think in the background in
it's the same, isn't it?!


So the question is:

- remove "Tools -> Media Player"
- remove "Insert -> Objects -> Sound" and "Insert -> Objects -> Video"

Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [Bug 32894] [Task] LibreOffice 3.3.1 release blockers / stoppers

2011-02-13 Thread bugzilla-daemon
https://bugs.freedesktop.org/show_bug.cgi?id=32894

--- Comment #20 from vitriol  2011-02-13 09:59:56 
@@ -250,7 +250,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
 }
 
-// Copy values from list in right order to ouer internal member.
+// Copy values from list in right order to our internal member.
 sal_Int32 nPropertyCount	=	seqValues.getLength()	;
 sal_Int32 nProperty			=	0		;
PST ---
Nominating Bug 34226. Regression from 3.3.0 final to 3.3.1 RC1
